@@ -261,7 +261,9 @@ newlines.</p></body></html>
         self.countunits(pofile, 2)
         # FIXME change this so that we check that the msgctxt is correctly added
         self.compareunit(pofile, 1, "Duplicate")
+        assert pofile.units[1].getlocations() == ['None+html.body.p:1-26']
         self.compareunit(pofile, 2, "Duplicate")
+        assert pofile.units[2].getlocations() == ['None+html.body.p:1-42']
 
     def test_multiline_reflow(self):
         """check that we reflow multiline content to make it more readable for translators"""
@@ -427,9 +429,9 @@ class TestHTML2POCommand(test_convert.TestConvertCommand, TestHTML2PO):
     convertmodule = html2po
     defaultoptions = {"progress": "none"}
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "--duplicates=DUPLICATESTYLE")
         options = self.help_check(options, "--keepcomments")
