@@ -1,5 +1,5 @@
-#!/usr/bin/env python2
 # -*- coding: utf-8 -*-
+from __future__ import print_function
 
 import warnings
 
@@ -10,7 +10,7 @@ from translate.misc import wStringIO
 from translate.storage import po
 
 
-class TestPOT2PO:
+class TestPOT2PO(object):
 
     def setup_method(self, method):
         warnings.resetwarnings()
@@ -286,7 +286,7 @@ msgstr "Sertifikate"
         posource = '# Some comment\n#. Extracted comment\n#: obsoleteme:10\nmsgid "One"\nmsgstr "Een"\n'
         expected = '# Some comment\n#~ msgid "One"\n#~ msgstr "Een"\n'
         newpo = self.convertpot(potsource, posource)
-        print(str(newpo))
+        print(bytes(newpo))
         newpounit = self.singleunit(newpo)
         assert str(newpounit) == expected
 
@@ -296,7 +296,7 @@ msgstr "Sertifikate"
         potsource = 'msgid ""\nmsgstr ""\n'
         posource = '#: obsoleteme:10\nmsgid "One"\nmsgstr ""\n'
         newpo = self.convertpot(potsource, posource)
-        print(str(newpo))
+        print(bytes(newpo))
         # We should only have the header
         assert len(newpo.units) == 1
 
@@ -394,7 +394,7 @@ msgstr ""
         newpo = self.convertpot(potsource, posource)
         print('Output Header:\n%s' % newpo)
         print('Expected Header:\n%s' % expected)
-        assert str(newpo) == expected
+        assert bytes(newpo).decode('utf-8') == expected
 
     def test_merging_comments(self):
         """Test that we can merge comments correctly"""
@@ -462,7 +462,7 @@ msgstr "teks"
 """
         newpo = self.convertpot(potsource, posource)
         print(newpo)
-        assert poexpected in str(newpo)
+        assert poexpected in bytes(newpo).decode('utf-8')
 
     def test_msgctxt_multiline(self):
         """Test multiline msgctxt fields."""
@@ -651,8 +651,8 @@ msgstr "trans"
         potsource = r'''
 msgid ""
 msgstr ""
-"X-Merge-On: location\n"
 "X-Accelerator-Marker: &\n"
+"X-Merge-On: location\n"
 
 
 #: bla
@@ -725,9 +725,9 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=INTEGER; plural=EXPRESSION;\n"
+"X-Accelerator-Marker: &\n"
 "X-Generator: Translate Toolkit 0.10rc2\n"
 "X-Merge-On: location\n"
-"X-Accelerator-Marker: &\n"
 
 #: new_disassociated_mozilla_accesskey
 msgid "R"
@@ -764,9 +764,9 @@ msgstr ""
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=(n != 1);\n"
+"X-Accelerator-Marker: &\n"
 "X-Generator: Translate Toolkit 0.10rc2\n"
 "X-Merge-On: location\n"
-"X-Accelerator-Marker: &\n"
 
 #: new_disassociated_mozilla_accesskey
 msgid "R"
@@ -775,16 +775,16 @@ msgstr ""
         newpo = self.convertpot(potsource, posource)
         print('Output:\n%s' % newpo)
         print('Expected:\n%s' % expected)
-        assert str(newpo) == expected
+        assert bytes(newpo).decode('utf-8') == expected
 
 
 class TestPOT2POCommand(test_convert.TestConvertCommand, TestPOT2PO):
     """Tests running actual pot2po commands on files"""
     convertmodule = pot2po
 
-    def test_help(self):
+    def test_help(self, capsys):
         """tests getting help"""
-        options = test_convert.TestConvertCommand.test_help(self)
+        options = test_convert.TestConvertCommand.test_help(self, capsys)
         options = self.help_check(options, "-t TEMPLATE, --template=TEMPLATE")
         options = self.help_check(options, "-P, --pot")
         options = self.help_check(options, "--tm")
