@@ -269,6 +269,33 @@ class TestPYPOFile(test_po.TestPOFile):
         print(bytes(oldfile))
         assert len(oldfile.units) == 1
 
+    def test_unicode_header(self):
+        """checks that unicode header is parsed and saved correctly"""
+        posource = r'''msgid ""
+msgstr ""
+"PO-Revision-Date: 2006-02-09 23:33+0200\n"
+"MIME-Version: 1.0\n"
+"Content-Type: text/plain; charset=UTF-8\n"
+"Content-Transfer-Encoding: 8-bit\n"
+"Zkouška: něco\n"
+'''.encode('utf-8')
+        pofile = self.poparse(posource)
+        assert pofile.parseheader() == {
+            'Content-Transfer-Encoding': '8-bit',
+            'Content-Type': 'text/plain; charset=UTF-8',
+            'MIME-Version': '1.0',
+            'PO-Revision-Date': '2006-02-09 23:33+0200',
+            'Zkouška': 'něco'
+        }
+        update = {'zkouška': 'else'}
+        pofile.updateheader(add=True, **update)
+        assert pofile.units[0].target == """PO-Revision-Date: 2006-02-09 23:33+0200
+MIME-Version: 1.0
+Content-Type: text/plain; charset=UTF-8
+Content-Transfer-Encoding: 8-bit
+Zkouška: else
+"""
+
     def test_prevmsgid_parse(self):
         """checks that prevmsgid (i.e. #|) is parsed and saved correctly"""
         posource = r'''msgid ""
@@ -399,3 +426,38 @@ msgstr ""
         assert len(pofile.units) == 1
         assert pofile.units[0].source == 'test me'
         assert bytes(pofile) == posource
+
+    def test_mixed_newlines_header(self):
+        """checks that mixed newlines are properly parsed"""
+        posource = b'''# Polish message file for YaST2 (@memory@).\r
+# Copyright (C) 2005 SUSE Linux Products GmbH.\r
+msgid ""
+msgstr ""
+"Project-Id-Version: YaST (@memory@)\\n"
+
+#. Rich text title for FcoeClient in proposals
+#: src/clients/fcoe-client_proposal.rb:82
+msgid "FcoeClient"
+msgstr "FcoeClient"
+'''
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 2
+        assert pofile.units[0].source == ''
+        assert pofile.units[1].source == 'FcoeClient'
+        print(repr(bytes(pofile)))
+        assert bytes(pofile) == posource
+
+    def test_bom(self):
+        """checks that BOM is parsed"""
+        posource = '''msgid ""
+msgstr ""
+"Project-Id-Version: YaST (@memory@)\\n"
+
+msgid "FcoeClient"
+msgstr "FcoeClient"
+'''.encode('utf-8-sig')
+        pofile = self.poparse(posource)
+        assert len(pofile.units) == 2
+        assert pofile.units[0].source == ''
+        assert pofile.units[1].source == 'FcoeClient'
+        assert bytes(pofile) == posource[3:]
